SQL Optimization Patterns
ynulihao/AgentSkillOS
Master SQL query optimization, indexing strategies, and EXPLAIN analysis to dramatically improve database performance and eliminate slow queries.
Build a fused forward LayerNorm kernel for Triton-Ascend with row-wise mean and variance reductions, float32 accumulation, affine weight and bias, and masked feature tiles.
$ npx skills add Krusty84/triton-ascend-agent-dev-kit --skill build-triton-ascend-layer-norm -a claude-codeProject install by default; add -g for ~/.claude/skills/.
$ gh skill install Krusty84/triton-ascend-agent-dev-kit build-triton-ascend-layer-norm --agent claude-codeProject scope by default; add --scope user for a personal install. Needs GitHub CLI 2.90.0 or later (public preview).
$ git clone --depth 1 https://github.com/Krusty84/triton-ascend-agent-dev-kit.git skills-src && mkdir -p .claude/skills && cp -r skills-src/skills/build-triton-ascend-layer-norm .claude/skills/build-triton-ascend-layer-norm && rm -rf skills-srcUse ~/.claude/skills/ instead of .claude/skills for a personal install. The folder must contain SKILL.md.
Claude Code skills documentation · loads skills from .claude/skills/
Install the "build-triton-ascend-layer-norm" agent skill from https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/build-triton-ascend-layer-norm into .claude/skills/build-triton-ascend-layer-norm/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "build-triton-ascend-layer-norm", then confirm the skill loads.Claude Code copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
$skill-installer install https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/build-triton-ascend-layer-normType this inside Codex. $skill-installer <name> installs a curated skill from openai/skills. The installer writes to $CODEX_HOME/skills (default ~/.codex/skills). Restart Codex if the skill does not show up.
$ npx skills add Krusty84/triton-ascend-agent-dev-kit --skill build-triton-ascend-layer-norm -a codexProject install goes to .agents/skills/; add -g for ~/.codex/skills/.
$ gh skill install Krusty84/triton-ascend-agent-dev-kit build-triton-ascend-layer-norm --agent codexProject scope by default (.agents/skills/); add --scope user for a personal install.
$ git clone --depth 1 https://github.com/Krusty84/triton-ascend-agent-dev-kit.git skills-src && mkdir -p .agents/skills && cp -r skills-src/skills/build-triton-ascend-layer-norm .agents/skills/build-triton-ascend-layer-norm && rm -rf skills-srcUse ~/.agents/skills/ instead of .agents/skills for a personal install.
Codex skills documentation · loads skills from .agents/skills/
Install the "build-triton-ascend-layer-norm" agent skill from https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/build-triton-ascend-layer-norm into .agents/skills/build-triton-ascend-layer-norm/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "build-triton-ascend-layer-norm", then confirm the skill loads.Codex copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
$ npx skills add Krusty84/triton-ascend-agent-dev-kit --skill build-triton-ascend-layer-norm -a cursorProject install goes to .agents/skills/; add -g for ~/.cursor/skills/.
$ gh skill install Krusty84/triton-ascend-agent-dev-kit build-triton-ascend-layer-norm --agent cursorProject scope by default (.agents/skills/); add --scope user for a personal install.
$ git clone --depth 1 https://github.com/Krusty84/triton-ascend-agent-dev-kit.git skills-src && mkdir -p .cursor/skills && cp -r skills-src/skills/build-triton-ascend-layer-norm .cursor/skills/build-triton-ascend-layer-norm && rm -rf skills-srcUse ~/.cursor/skills/ instead of .cursor/skills for a personal install.
Cursor skills documentation · loads skills from .cursor/skills/, .agents/skills/, .claude/skills/, .codex/skills/
Install the "build-triton-ascend-layer-norm" agent skill from https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/build-triton-ascend-layer-norm into .cursor/skills/build-triton-ascend-layer-norm/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "build-triton-ascend-layer-norm", then confirm the skill loads.Cursor copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
$ gemini skills install https://github.com/Krusty84/triton-ascend-agent-dev-kit.git --path skills/build-triton-ascend-layer-norm--scope user (default) or --scope workspace; --path is the subfolder of the repo that holds the skill; --consent skips the security confirmation prompt.
$ npx skills add Krusty84/triton-ascend-agent-dev-kit --skill build-triton-ascend-layer-norm -a gemini-cliProject install goes to .agents/skills/; add -g for ~/.gemini/skills/.
$ gh skill install Krusty84/triton-ascend-agent-dev-kit build-triton-ascend-layer-norm --agent gemini-cliProject scope by default (.agents/skills/); add --scope user for a personal install.
$ git clone --depth 1 https://github.com/Krusty84/triton-ascend-agent-dev-kit.git skills-src && mkdir -p .gemini/skills && cp -r skills-src/skills/build-triton-ascend-layer-norm .gemini/skills/build-triton-ascend-layer-norm && rm -rf skills-srcUse ~/.gemini/skills/ instead of .gemini/skills for a personal install, then run /skills reload.
Gemini CLI skills documentation · loads skills from .gemini/skills/, .agents/skills/
Install the "build-triton-ascend-layer-norm" agent skill from https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/build-triton-ascend-layer-norm into .gemini/skills/build-triton-ascend-layer-norm/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "build-triton-ascend-layer-norm", then confirm the skill loads.Gemini CLI copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
$ gh skill install Krusty84/triton-ascend-agent-dev-kit build-triton-ascend-layer-normInstalls for Copilot at project scope by default; add --scope user for a personal install. Preview a skill first with gh skill preview. Needs GitHub CLI 2.90.0 or later (public preview).
$ npx skills add Krusty84/triton-ascend-agent-dev-kit --skill build-triton-ascend-layer-norm -a github-copilotProject install goes to .agents/skills/; add -g for ~/.copilot/skills/.
$ git clone --depth 1 https://github.com/Krusty84/triton-ascend-agent-dev-kit.git skills-src && mkdir -p .github/skills && cp -r skills-src/skills/build-triton-ascend-layer-norm .github/skills/build-triton-ascend-layer-norm && rm -rf skills-srcUse ~/.copilot/skills/ instead of .github/skills for a personal install. Commit .github/skills so cloud agent and code review can use it.
GitHub Copilot skills documentation · loads skills from .github/skills/, .claude/skills/, .agents/skills/
Install the "build-triton-ascend-layer-norm" agent skill from https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/build-triton-ascend-layer-norm into .github/skills/build-triton-ascend-layer-norm/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "build-triton-ascend-layer-norm", then confirm the skill loads.GitHub Copilot copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
$ npx skills add Krusty84/triton-ascend-agent-dev-kit --skill build-triton-ascend-layer-norm -a opencodeOpenCode documents no install command of its own. Project install goes to .agents/skills/; add -g for ~/.config/opencode/skills/.
$ gh skill install Krusty84/triton-ascend-agent-dev-kit build-triton-ascend-layer-norm --agent opencodeProject scope by default (.agents/skills/); add --scope user for a personal install.
$ git clone --depth 1 https://github.com/Krusty84/triton-ascend-agent-dev-kit.git skills-src && mkdir -p .opencode/skills && cp -r skills-src/skills/build-triton-ascend-layer-norm .opencode/skills/build-triton-ascend-layer-norm && rm -rf skills-srcUse ~/.config/opencode/skills/ instead of .opencode/skills for a personal install.
OpenCode skills documentation · loads skills from .opencode/skills/, .claude/skills/, .agents/skills/
Install the "build-triton-ascend-layer-norm" agent skill from https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/build-triton-ascend-layer-norm into .opencode/skills/build-triton-ascend-layer-norm/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "build-triton-ascend-layer-norm", then confirm the skill loads.OpenCode copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
build-triton-ascend-layer-normBuild a fused forward LayerNorm kernel for Triton-Ascend with row-wise mean and variance reductions, float32 accumulation, affine weight and bias, and masked feature tiles.
Build Triton Ascend Layer Norm is an agent skill from Krusty84/triton-ascend-agent-dev-kit. Build a fused forward LayerNorm kernel for Triton-Ascend with row-wise mean and variance reductions, float32 accumulation, affine weight and bias, and masked feature tiles. Use when an agent needs LayerNorm over the last dimension on Ascend NPU or needs a reusable two-pass reduction pattern for normalization kernels.
Its SKILL.md is about 660 tokens, which your agent loads only when the skill is triggered. It is a single SKILL.md file with no bundled scripts.
It sits in Databases, covering Database schema design. The repository describes itself as: A toolkit for AI agents used for development on Triton-Ascend for Ascend NPU. The licence is Apache-2.0.
5 steps, taken from the first numbered list in SKILL.md.
Read from SKILL.md and the folder at commit 4ab5ee7. It shows what the files ask for, not the result of running them.
Pre-approves nothing: there is no allowed-tools line, so your agent's usual permission prompts apply.
From allowed-tools in the SKILL.md frontmatter.
No scripts in the folder and no shell commands in SKILL.md (its code samples are python).
From the folder's file list and the shell code blocks in SKILL.md.
No URLs in SKILL.md.
From URLs in SKILL.md, links to its own repository left out.
Names no API keys, tokens, secrets or passwords.
From names ending in _API_KEY, _TOKEN, _SECRET, _KEY or _PASSWORD in SKILL.md.
Build Triton Ascend Layer Norm loads about 659 tokens when it runs. Until then it costs about 87 tokens; SKILL.md has 230 words of instructions outside code blocks.
Estimates: characters ÷ 4, the usual rule of thumb; real counts depend on the model's tokenizer. Scripts and assets cost tokens only if the agent reads them.
The automated check found no risky patterns in SKILL.md.
Automated static check — not a guarantee. Review scripts before installing. It scans the text of SKILL.md for risky patterns (piping downloads into a shell, reading credential files, hidden Unicode, destructive commands); files beside SKILL.md are not scanned.
The full file from Krusty84/triton-ascend-agent-dev-kit at commit 4ab5ee7, republished under its Apache-2.0 licence (© Krusty84). 230 words, ~659 tokens.
.claude/skills/build-triton-ascend-layer-norm/SKILL.md (or your agent's skills folder).Implement the forward equation y = ((x - mean) / sqrt(var + eps)) * weight + bias over the final tensor dimension.
row = tl.program_id(0)
x_row = X + row * stride
y_row = Y + row * stride
mean_acc = tl.zeros([BLOCK_SIZE], tl.float32)
for start in range(0, N, BLOCK_SIZE):
cols = start + tl.arange(0, BLOCK_SIZE)
mean_acc += tl.load(x_row + cols, mask=cols < N, other=0.0).to(tl.float32)
mean = tl.sum(mean_acc, axis=0) / N
var_acc = tl.zeros([BLOCK_SIZE], tl.float32)
for start in range(0, N, BLOCK_SIZE):
cols = start + tl.arange(0, BLOCK_SIZE)
value = tl.load(x_row + cols, mask=cols < N, other=0.0).to(tl.float32)
centered = tl.where(cols < N, value - mean, 0.0)
var_acc += centered * centered
rstd = 1.0 / tl.sqrt(tl.sum(var_acc, axis=0) / N + eps)In the final tiled pass, load weight and bias with the same mask, compute (value - mean) * rstd * weight + bias, and store to y_row.
Compare with torch.nn.functional.layer_norm using the same eps, weight, and bias. Cover float16, bfloat16, and float32, multiple N values including non-multiples of BLOCK_SIZE, and use an explicit tolerance justified by dtype.
© Krusty84, Apache-2.0. Rendered from Markdown: HTML in the file is shown as text, images as links, and headings moved down two levels. Raw file
Just SKILL.md in skills/build-triton-ascend-layer-norm of Krusty84/triton-ascend-agent-dev-kit.
Open the folder on GitHubat commit 4ab5ee7
Build Triton Ascend Layer Norm next to the 5 skills that share the most tags, products or categories with it. Stars are the repository's; “used in” counts other GitHub owners with a copy.
| Skill | Stars | Used in | Tokens | Auto-check | Licence | Repo updated |
|---|---|---|---|---|---|---|
| Build Triton Ascend Layer Norm this skillKrusty84/triton-ascend-agent-dev-kit | 106 | — | ~659 | Automated safety check: Pass | Apache-2.0 | |
| SQL Optimization Patternsynulihao/AgentSkillOS | 618 | 11 repos | ~3.3k | Automated safety check: Pass | None | |
| Datamodellmnimbalyst/nimbalyst | 1.9k | — | ~713 | Automated safety check: Pass | MIT | |
| Add Mpk Taskmirage-project/mirage | 2.5k | — | ~4.5k | Automated safety check: Pass | Apache-2.0 | |
| B200 Flash Attention4 Plannermirage-project/mirage | 2.5k | — | ~1.9k | Automated safety check: Pass | Apache-2.0 | |
| Experiment Auditwanshuiyin/Auto-claude-code-research-in-sleep | 17k | 1 repos | ~2.7k | Automated safety check: Notes | MIT |
ynulihao/AgentSkillOS
Master SQL query optimization, indexing strategies, and EXPLAIN analysis to dramatically improve database performance and eliminate slow queries.
nimbalyst/nimbalyst
Create visual data models for database schemas using Nimbalyst's DataModelLM editor.
mirage-project/mirage
Step-by-step guide for adding a new task implementation to Mirage Persistent Kernel (MPK).
mirage-project/mirage
A skill your agent uses when the user wants to design or extend a FlashAttention-style forward kernel on B200/Blackwell, involving the two MMAs QKᵀ and PV, online softmax, S/P/O in TMEM, warp roles…
wanshuiyin/Auto-claude-code-research-in-sleep
Audit experiment integrity before claiming results. An agent skill from wanshuiyin/Auto-claude-code-research-in-sleep.
fastrepl/anarlog
Design or review schemas for crates/cloudsync using SQLite Sync constraints, not generic SQLite advice.
Krusty84/triton-ascend-agent-dev-kit
Implements request-to-token-pool copies for Triton kernels on Ascend NPUs, replacing loop-carried vector offsets with fixed-offset block loops that compile reliably.
Krusty84/triton-ascend-agent-dev-kit
Writes a Triton kernel pattern for Ascend NPU that gathers several indexed token rows per program into an on-chip buffer and stores one contiguous output tile, for MoE-style token reordering.
Krusty84/triton-ascend-agent-dev-kit
Builds Triton-Ascend kernels that pack sorted token assignments into fixed expert-capacity tensors, restore top-k outputs and compute router-weight gradients on Ascend NPUs.
Krusty84/triton-ascend-agent-dev-kit
Guides building a FlashAttention-v2-style fused forward attention kernel for Triton-Ascend on Ascend NPU, with online softmax, causal staging and float32 accumulation.
Krusty84/triton-ascend-agent-dev-kit
Builds a fused row-wise softmax kernel for Triton-Ascend that reads and writes each row once, handling padding, strides and masked loads on Ascend NPUs.
Krusty84/triton-ascend-agent-dev-kit
Build Ascend-friendly MoE gather, scatter, and router-weight-gradient kernels with vector-core-sized grids, UB-aware row/column tiling, and CANN slice extensions.
Categories
Build a fused forward LayerNorm kernel for Triton-Ascend with row-wise mean and variance reductions, float32 accumulation, affine weight and bias, and masked feature tiles. Build Triton Ascend Layer Norm is an agent skill from Krusty84/triton-ascend-agent-dev-kit. Build a fused forward LayerNorm kernel for Triton-Ascend with row-wise mean and variance reductions, float32 accumulation, affine weight and bias, and masked feature tiles.
Build Triton Ascend Layer Norm fits situations like: an agent needs LayerNorm over the last dimension on Ascend NPU; needs a reusable two-pass reduction pattern for normalization kernels.
Run `npx skills add Krusty84/triton-ascend-agent-dev-kit --skill build-triton-ascend-layer-norm -a claude-code`. Or copy the skill folder (skills/build-triton-ascend-layer-norm in Krusty84/triton-ascend-agent-dev-kit) into .claude/skills/build-triton-ascend-layer-norm in your project. Claude Code loads it when a task matches its description.
Run `npx skills add Krusty84/triton-ascend-agent-dev-kit --skill build-triton-ascend-layer-norm -a codex`. Or copy the skill folder (skills/build-triton-ascend-layer-norm in Krusty84/triton-ascend-agent-dev-kit) into .agents/skills/build-triton-ascend-layer-norm in your project. Codex loads it when a task matches its description.
Cursor, Gemini CLI, GitHub Copilot and OpenCode also load SKILL.md folders. With the skills CLI, run `npx skills add Krusty84/triton-ascend-agent-dev-kit --skill build-triton-ascend-layer-norm -a cursor` (or -a gemini-cli, github-copilot or opencode for the others). To copy it by hand, put the folder in .cursor/skills/build-triton-ascend-layer-norm, .gemini/skills/build-triton-ascend-layer-norm, .github/skills/build-triton-ascend-layer-norm and .opencode/skills/build-triton-ascend-layer-norm in your project.
SKILL.md names no scripts, command-line tools or credentials: Build Triton Ascend Layer Norm is instructions for the agent only. Our summary lists: Python 3.
SKILL.md contains no URLs. Any network use would come from the scripts or tools the agent runs. This is read from the text; nothing was executed.
Our automated static check of SKILL.md found no risky patterns, such as piping downloads into a shell, reading credential files or hidden Unicode. It is not a guarantee. Review the folder before installing.
Build Triton Ascend Layer Norm is published under the Apache-2.0 licence (the repository's licence). It allows redistribution, so the full SKILL.md is shown on this page.
About 659 tokens (SKILL.md is roughly 2.6k characters). Agents keep only the skill's name and description in context until a task matches; then they load SKILL.md in full.
Skills that share tags, products or a category with Build Triton Ascend Layer Norm: SQL Optimization Patterns (ynulihao/AgentSkillOS, 618 stars), Datamodellm (nimbalyst/nimbalyst, 1.9k stars), Add Mpk Task (mirage-project/mirage, 2.5k stars) and B200 Flash Attention4 Planner (mirage-project/mirage, 2.5k stars). The comparison table on this page puts their stars, adoption, token cost, safety result and licence side by side.
Krusty84 (a GitHub user) maintains it in Krusty84/triton-ascend-agent-dev-kit, which has 106 GitHub stars. The repository holds 23 skills in this directory. The repository was last updated on August 15, 2026.
Source: Krusty84/triton-ascend-agent-dev-kit on GitHub. Facts on this page come from the repository at the commit we read; the author's words are quoted as theirs.